module.exports={A:{A:{"2436":"J D E F A B 5C"},B:{"260":"N O","2436":"C K L G M","8196":"0 1 2 3 4 5 6 7 8 9 P H Q R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB"},C:{"2":"6C YC I eB J D E F A B C K L G M N O fB AB BB 9C AD","772":"CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB","4100":"0 1 2 3 4 5 6 7 8 9 rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B ZC 9B aC AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC 7C 8C"},D:{"2":"I eB J D E F A B C","2564":"K L G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB","8196":"0 1 2 3 4 5 6 7 8 9 8B ZC 9B aC AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC","10244":"tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B"},E:{"1":"C K L G TC GD HD ID gC hC UC JD VC iC jC kC lC mC KD WC nC oC pC qC rC LD XC sC tC uC vC wC xC yC zC 0C 1C 2C MD","16":"BD eC","2308":"A B fC SC","2820":"I eB J D E F CD DD ED FD"},F:{"2":"F B ND OD PD QD SC 3C RD","16":"C","516":"TC","2564":"G M N O fB AB BB CB DB EB FB GB HB IB JB","8196":"0 1 2 3 4 5 6 7 8 9 vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z","10244":"gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB"},G:{"1":"dD eD fD gD hD iD jD kD lD gC hC UC mD VC iC jC kC lC mC nD WC nC oC pC qC rC oD XC sC tC uC vC wC xC yC zC 0C 1C 2C","2":"eC SD 4C","2820":"E TD UD VD WD XD YD ZD aD bD cD"},H:{"2":"pD"},I:{"2":"YC I qD rD sD tD 4C","260":"KB","2308":"uD vD"},J:{"2":"D","2308":"A"},K:{"2":"A B C SC 3C","16":"TC","8196":"H"},L:{"8196":"KB"},M:{"1028":"RC"},N:{"2":"A B"},O:{"8196":"UC"},P:{"2052":"wD xD","2308":"I","8196":"AB BB CB DB EB FB GB HB IB JB yD zD 0D fC 1D 2D 3D 4D 5D VC WC XC 6D"},Q:{"8196":"7D"},R:{"8196":"8D"},S:{"4100":"9D AE"}},B:5,C:"Synchronous Clipboard API",D:true};
