module.exports={A:{A:{"2":"J D E 5C","520":"F A B"},B:{"1":"0 1 2 3 4 5 6 7 8 9 P H Q R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB","8":"C K","388":"L G M N O"},C:{"1":"0 1 2 3 4 5 6 7 8 9 IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B ZC 9B aC AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC 7C 8C","2":"6C YC 9C AD","132":"I eB J D E F A B C K L G M N O fB AB BB CB DB EB FB GB HB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B ZC 9B aC AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC","2":"I eB","132":"J D E F A B C K L G M N O fB AB BB CB DB EB"},E:{"2":"BD","8":"I eB eC CD","520":"J D E F A B C DD ED FD fC SC","16385":"VC iC jC kC lC mC KD WC nC oC pC qC rC LD XC sC tC uC vC wC xC yC zC 0C 1C 2C MD","17412":"K TC GD","23556":"L","24580":"G HD ID gC hC UC JD"},F:{"1":"0 1 2 3 4 5 6 7 8 9 M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z","2":"F ND OD PD","132":"B C G QD SC 3C RD TC"},G:{"2":"E eC SD 4C TD UD VD WD XD YD ZD aD bD cD dD","16385":"qC rC oD XC sC tC uC vC wC xC yC zC 0C 1C 2C","17412":"eD fD gD hD iD","19460":"jD kD lD gC hC UC mD VC iC jC kC lC mC nD WC nC oC pC"},H:{"2":"pD"},I:{"1":"KB","2":"qD rD","132":"YC I sD tD 4C uD vD"},J:{"2":"D A"},K:{"1":"H","2":"A B C SC 3C TC"},L:{"1":"KB"},M:{"1":"RC"},N:{"8":"A B"},O:{"1":"UC"},P:{"1":"AB BB CB DB EB FB GB HB IB JB wD xD yD zD 0D fC 1D 2D 3D 4D 5D VC WC XC 6D","132":"I"},Q:{"1":"7D"},R:{"1":"8D"},S:{"1":"9D AE"}},B:6,C:"WebM video format",D:true};
