module.exports={A:{A:{"1":"B","2":"J D E F A 5C"},B:{"1":"0 1 2 3 4 5 6 7 8 9 L G M N O P H Q R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB","129":"C K"},C:{"1":"0 1 2 3 4 5 6 7 8 9 0B 1B 2B 3B 4B 5B 6B 7B 8B ZC 9B aC AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC 7C 8C","2":"6C YC","260":"G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB","804":"I eB J D E F A B C K L 9C AD"},D:{"1":"0 1 2 3 4 5 6 7 8 9 6B 7B 8B ZC 9B aC AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC","260":"1B 2B 3B 4B 5B","388":"gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B","1412":"G M N O fB AB BB CB DB EB FB GB HB IB JB","1956":"I eB J D E F A B C K L"},E:{"1":"hC UC JD VC iC jC kC lC mC KD WC nC oC pC qC rC LD XC sC tC uC vC wC xC yC zC 0C 1C 2C MD","129":"A B C K L G FD fC SC TC GD HD ID gC","1412":"J D E F DD ED","1956":"I eB BD eC CD"},F:{"1":"0 1 2 3 4 5 6 7 8 9 tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z","2":"F ND OD","260":"oB pB qB rB sB","388":"G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB","1796":"PD QD","1828":"B C SC 3C RD TC"},G:{"1":"hC UC mD VC iC jC kC lC mC nD WC nC oC pC qC rC oD XC sC tC uC vC wC xC yC zC 0C 1C 2C","129":"YD ZD aD bD cD dD eD fD gD hD iD jD kD lD gC","1412":"E UD VD WD XD","1956":"eC SD 4C TD"},H:{"1828":"pD"},I:{"1":"KB","388":"uD vD","1956":"YC I qD rD sD tD 4C"},J:{"1412":"A","1924":"D"},K:{"1":"H","2":"A","1828":"B C SC 3C TC"},L:{"1":"KB"},M:{"1":"RC"},N:{"1":"B","2":"A"},O:{"1":"UC"},P:{"1":"AB BB CB DB EB FB GB HB IB JB yD zD 0D fC 1D 2D 3D 4D 5D VC WC XC 6D","260":"wD xD","388":"I"},Q:{"1":"7D"},R:{"1":"8D"},S:{"1":"AE","260":"9D"}},B:4,C:"CSS3 Border images",D:true};
