module.exports={A:{A:{"1":"F A B","2":"J D E 5C"},B:{"1":"0 1 2 3 4 5 6 7 8 9 C K L G M N O P H Q R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB"},C:{"1":"0 1 2 3 4 5 6 7 8 9 0B 1B 2B 3B 4B 5B 6B 7B 8B ZC 9B aC AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC 7C 8C","257":"I eB J D E F A B C K L G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB","289":"YC 9C AD","292":"6C"},D:{"1":"0 1 2 3 4 5 6 7 8 9 eB J D E F A B C K L G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B ZC 9B aC AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC","33":"I"},E:{"1":"eB D E F A B C K L G ED FD fC SC TC GD HD ID gC hC UC JD VC iC jC kC lC mC KD WC nC oC pC qC rC LD XC sC tC uC vC wC xC yC zC 0C 1C 2C MD","33":"I BD eC","129":"J CD DD"},F:{"1":"0 1 2 3 4 5 6 7 8 9 B C G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z PD QD SC 3C RD TC","2":"F ND OD"},G:{"1":"E SD 4C TD UD VD WD XD YD ZD aD bD cD dD eD fD gD hD iD jD kD lD gC hC UC mD VC iC jC kC lC mC nD WC nC oC pC qC rC oD XC sC tC uC vC wC xC yC zC 0C 1C 2C","33":"eC"},H:{"2":"pD"},I:{"1":"YC I KB rD sD tD 4C uD vD","33":"qD"},J:{"1":"D A"},K:{"1":"B C H SC 3C TC","2":"A"},L:{"1":"KB"},M:{"1":"RC"},N:{"1":"A B"},O:{"1":"UC"},P:{"1":"I AB BB CB DB EB FB GB HB IB JB wD xD yD zD 0D fC 1D 2D 3D 4D 5D VC WC XC 6D"},Q:{"1":"7D"},R:{"1":"8D"},S:{"1":"AE","257":"9D"}},B:4,C:"CSS3 Border-radius (rounded corners)",D:true};
