module.exports={A:{A:{"1":"B","4":"J D E F A 5C"},B:{"1":"C K L G M","129":"0 1 2 3 4 5 6 7 8 9 N O P H Q R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB"},C:{"1":"J D E F A B C K L G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B","4":"6C YC I eB 9C AD","129":"0 1 2 3 4 5 6 7 8 9 1B 2B 3B 4B 5B 6B 7B 8B ZC 9B aC AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC 7C 8C"},D:{"1":"vB wB xB yB zB 0B 1B 2B 3B 4B","4":"I eB J","129":"0 1 2 3 4 5 6 7 8 9 D E F A B C K L G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB 5B 6B 7B 8B ZC 9B aC AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC"},E:{"4":"I eB BD eC","129":"J D E F A B C K L G CD DD ED FD fC SC TC GD HD ID gC hC UC JD VC iC jC kC lC mC KD WC nC oC pC qC rC LD XC sC tC uC vC wC xC yC zC 0C 1C 2C MD"},F:{"1":"C iB jB kB lB mB nB oB pB qB rB SC 3C RD TC","4":"F B ND OD PD QD","129":"0 1 2 3 4 5 6 7 8 9 G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z"},G:{"4":"eC SD 4C","129":"E TD UD VD WD XD YD ZD aD bD cD dD eD fD gD hD iD jD kD lD gC hC UC mD VC iC jC kC lC mC nD WC nC oC pC qC rC oD XC sC tC uC vC wC xC yC zC 0C 1C 2C"},H:{"4":"pD"},I:{"4":"qD rD sD","129":"YC I KB tD 4C uD vD"},J:{"129":"D A"},K:{"1":"C SC 3C TC","4":"A B","129":"H"},L:{"129":"KB"},M:{"129":"RC"},N:{"1":"B","4":"A"},O:{"129":"UC"},P:{"129":"I AB BB CB DB EB FB GB HB IB JB wD xD yD zD 0D fC 1D 2D 3D 4D 5D VC WC XC 6D"},Q:{"129":"7D"},R:{"129":"8D"},S:{"1":"9D","129":"AE"}},B:1,C:"dataset & data-* attributes",D:true};
