module.exports={A:{A:{"2":"J D E F A B 5C"},B:{"2":"C K L G M N O","1025":"0 1 2 3 4 5 6 7 8 9 c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB","1537":"P H Q R S T U V W X Y Z a b"},C:{"2":"6C","932":"YC I eB J D E F A B C K L G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B ZC 9B aC AC BC CC DC 9C AD","2308":"0 1 2 3 4 5 6 7 8 9 EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC 7C 8C"},D:{"2":"I eB J D E F A B C K L G M N O fB AB BB","545":"CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB","1025":"0 1 2 3 4 5 6 7 8 9 c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC","1537":"wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B ZC 9B aC AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q R S T U V W X Y Z a b"},E:{"1":"VC iC jC kC lC mC KD WC nC oC pC qC rC LD XC sC tC uC vC wC xC yC zC 0C 1C 2C MD","2":"I eB J BD eC CD","516":"B C K L G SC TC GD HD ID gC hC UC JD","548":"F A FD fC","676":"D E DD ED"},F:{"2":"F B C ND OD PD QD SC 3C RD TC","513":"kB","545":"G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB","1025":"0 1 2 3 4 5 6 7 8 9 d e f g h i j k l m n o p q r s t u v w x y z","1537":"jB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC R S T U V W X Y Z a b c"},G:{"1":"VC iC jC kC lC mC nD WC nC oC pC qC rC oD XC sC tC uC vC wC xC yC zC 0C 1C 2C","2":"eC SD 4C TD UD","516":"jD kD lD gC hC UC mD","548":"XD YD ZD aD bD cD dD eD fD gD hD iD","676":"E VD WD"},H:{"2":"pD"},I:{"2":"YC I qD rD sD tD 4C","545":"uD vD","1025":"KB"},J:{"2":"D","545":"A"},K:{"2":"A B C SC 3C TC","1025":"H"},L:{"1025":"KB"},M:{"2308":"RC"},N:{"2":"A B"},O:{"1537":"UC"},P:{"545":"I","1025":"AB BB CB DB EB FB GB HB IB JB WC XC 6D","1537":"wD xD yD zD 0D fC 1D 2D 3D 4D 5D VC"},Q:{"1537":"7D"},R:{"1537":"8D"},S:{"932":"9D","2308":"AE"}},B:5,C:"Intrinsic & Extrinsic Sizing",D:true};
