module.exports={A:{A:{"2":"J D E 5C","2561":"A B","2692":"F"},B:{"1":"0 1 2 3 4 5 6 7 8 9 P H Q R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB","2561":"C K L G M N O"},C:{"1":"0 1 2 3 4 5 6 7 8 9 zB 0B 1B 2B 3B 4B 5B 6B 7B 8B ZC 9B aC AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC 7C 8C","16":"6C","1537":"I eB J D E F A B C K L G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB AD","1796":"YC 9C"},D:{"1":"0 1 2 3 4 5 6 7 8 9 EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC","16":"I eB J D E F A B C K L","1025":"lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B ZC 9B aC AC BC CC DC","1537":"G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB"},E:{"1":"L G GD HD ID gC hC UC JD VC iC jC kC lC mC KD WC nC oC pC qC rC LD XC sC tC uC vC wC xC yC zC 0C 1C 2C MD","16":"I eB J BD eC","1025":"D E F A B C DD ED FD fC SC","1537":"CD","4097":"K TC"},F:{"1":"0 1 2 3 4 5 6 7 8 9 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z TC","16":"F B C ND OD PD QD SC 3C","260":"RD","1025":"CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B","1537":"G M N O fB AB BB"},G:{"1":"gD hD iD jD kD lD gC hC UC mD VC iC jC kC lC mC nD WC nC oC pC qC rC oD XC sC tC uC vC wC xC yC zC 0C 1C 2C","16":"eC SD 4C","1025":"E WD XD YD ZD aD bD cD dD","1537":"TD UD VD","4097":"eD fD"},H:{"2":"pD"},I:{"16":"qD rD","1025":"KB vD","1537":"YC I sD tD 4C uD"},J:{"1025":"A","1537":"D"},K:{"1":"A B C H SC 3C TC"},L:{"1":"KB"},M:{"1":"RC"},N:{"2561":"A B"},O:{"1":"UC"},P:{"1025":"I AB BB CB DB EB FB GB HB IB JB wD xD yD zD 0D fC 1D 2D 3D 4D 5D VC WC XC 6D"},Q:{"1":"7D"},R:{"1":"8D"},S:{"1":"AE","1537":"9D"}},B:1,C:"input event",D:true};
