module.exports={A:{A:{"1":"B","2":"J D 5C","66":"E F A"},B:{"1":"C K L G M N O P H Q R S","2":"0 1 2 3 4 5 6 7 8 9 g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB","1540":"T U V W X Y Z a b c d e f"},C:{"1":"EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B ZC 9B aC AC BC CC DC EC FC","2":"0 1 2 3 4 5 6 7 8 9 6C YC I eB J D E F A B C K L G M N O fB AB BB CB f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC 7C 8C 9C AD","66":"DB","129":"GC HC IC JC KC LC MC NC OC PC","388":"QC P H Q bC R S T U V W X Y Z a b c d e"},D:{"1":"CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B ZC 9B aC AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q R S","2":"0 1 2 3 4 5 6 7 8 9 I eB J D E F A B C K L G M N O fB AB BB g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC","1540":"T U V W X Y Z a b c d e f"},E:{"1":"D E F A B C K ED FD fC SC TC","2":"I eB J BD eC CD DD","513":"L GD","1028":"G HD ID gC hC UC JD VC iC jC kC lC mC KD WC nC oC pC qC rC LD XC sC tC uC vC wC xC yC zC 0C 1C 2C MD"},F:{"1":"G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC TC","2":"0 1 2 3 4 5 6 7 8 9 F B C S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z ND OD PD QD SC 3C RD","1540":"LC MC NC OC PC QC P H Q bC R"},G:{"1":"E TD UD VD WD XD YD ZD aD bD cD dD eD fD gD hD iD","2":"eC SD 4C","1028":"jD kD lD gC hC UC mD VC iC jC kC lC mC nD WC nC oC pC qC rC oD XC sC tC uC vC wC xC yC zC 0C 1C 2C"},H:{"16":"pD"},I:{"2":"YC I KB qD rD sD tD 4C uD vD"},J:{"1":"A","2":"D"},K:{"1":"TC","2":"A B C H SC 3C"},L:{"2":"KB"},M:{"2":"RC"},N:{"1":"B","66":"A"},O:{"2":"UC"},P:{"1":"I wD xD yD zD 0D","2":"AB BB CB DB EB FB GB HB IB JB fC 1D 2D 3D 4D 5D VC WC XC 6D"},Q:{"16":"7D"},R:{"16":"8D"},S:{"1":"9D AE"}},B:7,C:"TLS 1.1",D:true};
