module.exports={A:{A:{"1":"A B","2":"J D E F 5C"},B:{"1":"C K L G M N O","516":"0 1 2 3 4 5 6 7 8 9 P H Q R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB"},C:{"132":"2B 3B 4B 5B 6B 7B 8B ZC 9B aC AC BC CC","164":"6C YC I eB J D E F A B C K L G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 9C AD","516":"DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC R S T U V W X Y Z","1028":"0 1 2 3 4 5 6 7 8 9 a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC 7C 8C"},D:{"420":"I eB J D E F A B C K L G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB","516":"0 1 2 3 4 5 6 7 8 9 0B 1B 2B 3B 4B 5B 6B 7B 8B ZC 9B aC AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC"},E:{"1":"A B C K L G fC SC TC GD HD ID gC hC UC JD VC iC jC kC lC mC KD WC nC oC pC qC rC LD XC sC tC uC vC wC xC yC zC 0C 1C 2C MD","132":"F FD","164":"D E ED","420":"I eB J BD eC CD DD"},F:{"1":"C SC 3C RD TC","2":"F B ND OD PD QD","420":"G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB","516":"0 1 2 3 4 5 6 7 8 9 nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z"},G:{"1":"ZD aD bD cD dD eD fD gD hD iD jD kD lD gC hC UC mD VC iC jC kC lC mC nD WC nC oC pC qC rC oD XC sC tC uC vC wC xC yC zC 0C 1C 2C","132":"XD YD","164":"E VD WD","420":"eC SD 4C TD UD"},H:{"1":"pD"},I:{"420":"YC I qD rD sD tD 4C uD vD","516":"KB"},J:{"420":"D A"},K:{"1":"C SC 3C TC","2":"A B","516":"H"},L:{"516":"KB"},M:{"1028":"RC"},N:{"1":"A B"},O:{"516":"UC"},P:{"420":"I","516":"AB BB CB DB EB FB GB HB IB JB wD xD yD zD 0D fC 1D 2D 3D 4D 5D VC WC XC 6D"},Q:{"516":"7D"},R:{"516":"8D"},S:{"164":"9D AE"}},B:4,C:"CSS3 Multiple column layout",D:true};
