module.exports={A:{A:{"2":"F A B 5C","8":"J D E"},B:{"2":"C K L G M N O","8":"P H Q R S T U V W X Y Z a b c d e","584":"f g h i j k l m n o p q","1025":"0 1 2 3 4 5 6 7 8 9 r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB"},C:{"1":"0 1 2 3 4 5 6 7 8 9 I eB J D E F A B C K L G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B ZC 9B aC AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC 7C 8C","129":"6C YC 9C AD"},D:{"1":"EB","8":"I eB J D E F A B C K L G M N O fB AB BB CB DB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B ZC 9B aC AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q R S T U V W X Y Z a b c d e","584":"f g h i j k l m n o p q","1025":"0 1 2 3 4 5 6 7 8 9 r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC"},E:{"1":"A B C K L G fC SC TC GD HD ID gC hC UC JD VC iC jC kC lC mC KD WC nC oC pC qC rC LD XC sC tC uC vC wC xC yC zC 0C 1C 2C MD","260":"I eB J D E F BD eC CD DD ED FD"},F:{"2":"F","8":"G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC","584":"R S T U V W X Y Z a b c","1025":"0 1 2 3 4 5 6 7 8 9 d e f g h i j k l m n o p q r s t u v w x y z","2052":"B C ND OD PD QD SC 3C RD TC"},G:{"1":"E TD UD VD WD XD YD ZD aD bD cD dD eD fD gD hD iD jD kD lD gC hC UC mD VC iC jC kC lC mC nD WC nC oC pC qC rC oD XC sC tC uC vC wC xC yC zC 0C 1C 2C","8":"eC SD 4C"},H:{"8":"pD"},I:{"8":"YC I qD rD sD tD 4C uD vD","1025":"KB"},J:{"1":"A","8":"D"},K:{"8":"A B C SC 3C TC","1025":"H"},L:{"1025":"KB"},M:{"1":"RC"},N:{"2":"A B"},O:{"8":"UC"},P:{"1":"BB CB DB EB FB GB HB IB JB","8":"I AB wD xD yD zD 0D fC 1D 2D 3D 4D 5D VC WC XC 6D"},Q:{"8":"7D"},R:{"8":"8D"},S:{"1":"9D AE"}},B:2,C:"MathML",D:true};
