module.exports={A:{A:{"2":"J D E F A B 5C"},B:{"1":"0 1 2 3 4 5 6 7 8 9 X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB","2":"C K L G M N O","1028":"V W","1540":"P H Q R S T U"},C:{"1":"0 1 2 3 4 5 6 7 8 9 EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC 7C 8C","2":"6C","164":"YC I eB J D E F A B C K L G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB 9C AD","1540":"rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B ZC 9B aC AC BC CC DC"},D:{"1":"0 1 2 3 4 5 6 7 8 9 X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC","292":"I eB J D E F A B C K L G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B ZC 9B aC AC BC CC DC EC FC GC","1028":"V W","1540":"HC IC JC KC LC MC NC OC PC QC P H Q R S T U"},E:{"1":"G ID gC hC UC JD VC iC jC kC lC mC KD WC nC oC pC qC rC LD XC sC tC uC vC wC xC yC zC 0C 1C 2C MD","292":"I eB J D E F A B C BD eC CD DD ED FD fC SC","1540":"K L TC GD","3076":"HD"},F:{"1":"0 1 2 3 4 5 6 7 8 9 OC PC QC P H Q bC R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z","2":"F B C ND OD PD QD SC 3C RD TC","292":"G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B","1028":"MC NC","1540":"6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC"},G:{"1":"lD gC hC UC mD VC iC jC kC lC mC nD WC nC oC pC qC rC oD XC sC tC uC vC wC xC yC zC 0C 1C 2C","292":"E eC SD 4C TD UD VD WD XD YD ZD aD bD cD dD","1540":"eD fD gD hD iD jD","3076":"kD"},H:{"2":"pD"},I:{"1":"KB","292":"YC I qD rD sD tD 4C uD vD"},J:{"292":"D A"},K:{"1":"H","2":"A B C SC 3C TC"},L:{"1":"KB"},M:{"1":"RC"},N:{"2":"A B"},O:{"1":"UC"},P:{"1":"AB BB CB DB EB FB GB HB IB JB 5D VC WC XC 6D","292":"I wD xD yD zD 0D","1540":"fC 1D 2D 3D 4D"},Q:{"1540":"7D"},R:{"1":"8D"},S:{"1":"AE","1540":"9D"}},B:5,C:"CSS Logical Properties",D:true};
