module.exports={A:{A:{"1":"A B","2":"J D E F 5C"},B:{"1":"0 1 2 3 4 5 6 7 8 9 P H Q R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB","2":"C K L G M N O"},C:{"1":"0 1 2 3 4 5 6 7 8 9 nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B ZC 9B aC AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC 7C 8C","2":"6C YC 9C AD","132":"I eB J D E F A B C K L G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B ZC 9B aC AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC","2":"I","16":"eB J D E BB CB DB EB FB","132":"F A B C K L G M N O fB AB"},E:{"1":"C K L G SC TC GD HD ID gC hC UC JD VC iC jC kC lC mC KD WC nC oC pC qC rC LD XC sC tC uC vC wC xC yC zC 0C 1C 2C MD","2":"I eB BD eC CD","132":"J D E F A B DD ED FD fC"},F:{"1":"0 1 2 3 4 5 6 7 8 9 G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z","2":"F B C ND OD PD QD SC 3C RD TC"},G:{"2":"UD VD","132":"E WD XD YD ZD aD bD cD dD eD fD gD hD iD jD kD lD gC hC UC mD VC iC jC kC lC mC nD WC nC oC pC qC rC oD XC sC tC uC vC wC xC yC zC 0C 1C 2C","514":"eC SD 4C TD"},H:{"2":"pD"},I:{"2":"qD rD sD","260":"YC I tD 4C","514":"KB uD vD"},J:{"132":"A","260":"D"},K:{"2":"A B C SC 3C TC","514":"H"},L:{"260":"KB"},M:{"2":"RC"},N:{"514":"A","1028":"B"},O:{"2":"UC"},P:{"260":"I AB BB CB DB EB FB GB HB IB JB wD xD yD zD 0D fC 1D 2D 3D 4D 5D VC WC XC 6D"},Q:{"260":"7D"},R:{"260":"8D"},S:{"1":"9D AE"}},B:1,C:"accept attribute for file input",D:true};
