module.exports={A:{A:{"2":"J D E 5C","260":"F A B"},B:{"2":"UB VB WB XB YB ZB aB bB cB dB","66":"9 LB MB NB OB PB QB RB SB TB","132":"0 1 2 3 4 5 6 7 8 P H Q R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z","260":"C K L G M N O"},C:{"2":"6C YC I eB XB YB ZB aB bB cB dB KB cC RC dC 7C 8C 9C AD","260":"0 1 2 3 4 5 6 7 8 9 J D E F A B C K L G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B ZC 9B aC AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB"},D:{"2":"SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC","16":"I eB J D E F A B C K L","66":"9 LB MB NB OB PB QB RB","132":"0 1 2 3 4 5 6 7 8 G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B ZC 9B aC AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z"},E:{"2":"xC yC zC 0C 1C 2C MD","16":"BD eC","132":"I eB J D E F A B C K L G CD DD ED FD fC SC TC GD HD ID gC hC UC JD VC iC jC kC lC mC KD WC nC oC pC qC rC LD XC sC tC uC vC wC"},F:{"1":"C RD TC","2":"F ND OD PD QD","16":"B SC 3C","66":"0 1 2 3 4 5 6 7 8 9 v w x y z","132":"G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u"},G:{"2":"xC yC zC 0C 1C 2C","16":"eC SD","132":"E 4C TD UD VD WD XD YD ZD aD bD cD dD eD fD gD hD iD jD kD lD gC hC UC mD VC iC jC kC lC mC nD WC nC oC pC qC rC oD XC sC tC uC vC wC"},H:{"2":"pD"},I:{"2":"KB","16":"qD rD","132":"YC I sD tD 4C uD vD"},J:{"132":"D A"},K:{"1":"C TC","2":"A","16":"B SC 3C","132":"H"},L:{"2":"KB"},M:{"2":"RC"},N:{"260":"A B"},O:{"132":"UC"},P:{"132":"I AB BB CB DB EB FB GB HB IB JB wD xD yD zD 0D fC 1D 2D 3D 4D 5D VC WC XC 6D"},Q:{"132":"7D"},R:{"132":"8D"},S:{"260":"9D AE"}},B:7,C:"Mutation events",D:true};
