module.exports={A:{A:{"2":"J D E 5C","132":"F A B"},B:{"1":"0 1 2 3 4 5 6 7 8 9 P H Q R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB","1028":"C K L G M N O"},C:{"1":"0 1 2 3 4 5 6 7 8 9 AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC 7C 8C","2":"6C YC","260":"I eB J D E F A B C K L G 9C AD","1028":"M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B ZC 9B aC"},D:{"1":"0 1 2 3 4 5 6 7 8 9 GC HC IC JC KC LC MC NC OC PC QC P H Q R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC","548":"I eB J D E F A B C K L G M N O fB AB BB CB DB EB FB GB HB IB","1028":"JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B ZC 9B aC AC BC CC DC EC FC"},E:{"1":"VC iC jC kC lC mC KD WC nC oC pC qC rC LD XC sC tC uC vC wC xC yC zC 0C 1C 2C MD","2":"BD eC","548":"I eB J D E F A B C K L G CD DD ED FD fC SC TC GD HD ID gC hC UC JD"},F:{"1":"0 1 2 3 4 5 6 7 8 9 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z TC","2":"F","548":"B C ND OD PD QD SC 3C RD","1028":"G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B"},G:{"1":"VC iC jC kC lC mC nD WC nC oC pC qC rC oD XC sC tC uC vC wC xC yC zC 0C 1C 2C","16":"eC","548":"E SD 4C TD UD VD WD XD YD ZD aD bD cD dD eD fD gD hD iD jD kD lD gC hC UC mD"},H:{"132":"pD"},I:{"1":"KB","16":"qD rD","548":"YC I sD tD 4C","1028":"uD vD"},J:{"548":"D A"},K:{"1":"H TC","548":"A B C SC 3C"},L:{"1":"KB"},M:{"1":"RC"},N:{"132":"A B"},O:{"1":"UC"},P:{"1":"AB BB CB DB EB FB GB HB IB JB fC 1D 2D 3D 4D 5D VC WC XC 6D","1028":"I wD xD yD zD 0D"},Q:{"1":"7D"},R:{"1":"8D"},S:{"1":"9D AE"}},B:4,C:"Media Queries: resolution feature",D:true};
