module.exports={A:{A:{"1":"B","2":"J D E F 5C","164":"A"},B:{"1":"0 1 2 3 4 5 6 7 8 9 C K L G M N O P H Q R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB"},C:{"1":"0 1 2 3 4 5 6 7 8 9 ZC 9B aC AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC 7C 8C","2":"6C YC I eB 9C AD","8":"J D E F A B C K L G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB","328":"rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B"},D:{"1":"0 1 2 3 4 5 6 7 8 9 5B 6B 7B 8B ZC 9B aC AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC","2":"I eB J D E F A B C K L G M N O fB AB BB","8":"CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B","584":"2B 3B 4B"},E:{"1":"K L G GD HD ID gC hC UC JD VC iC jC kC lC mC KD WC nC oC pC qC rC LD XC sC tC uC vC wC xC yC zC 0C 1C 2C MD","2":"I eB J BD eC CD","8":"D E F A B C DD ED FD fC SC","1096":"TC"},F:{"1":"0 1 2 3 4 5 6 7 8 9 sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z","2":"F B C ND OD PD QD SC 3C RD TC","8":"G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB","584":"pB qB rB"},G:{"1":"gD hD iD jD kD lD gC hC UC mD VC iC jC kC lC mC nD WC nC oC pC qC rC oD XC sC tC uC vC wC xC yC zC 0C 1C 2C","8":"E eC SD 4C TD UD VD WD XD YD ZD aD bD cD dD eD","6148":"fD"},H:{"2":"pD"},I:{"1":"KB","8":"YC I qD rD sD tD 4C uD vD"},J:{"8":"D A"},K:{"1":"H","2":"A","8":"B C SC 3C TC"},L:{"1":"KB"},M:{"1":"RC"},N:{"1":"B","36":"A"},O:{"1":"UC"},P:{"1":"AB BB CB DB EB FB GB HB IB JB xD yD zD 0D fC 1D 2D 3D 4D 5D VC WC XC 6D","2":"wD","8":"I"},Q:{"1":"7D"},R:{"1":"8D"},S:{"1":"AE","328":"9D"}},B:2,C:"Pointer events",D:true};
