"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = _classPrivateMethodInitSpec;
var _checkPrivateRedeclaration = require("./checkPrivateRedeclaration.js");
function _classPrivateMethodInitSpec(obj, privateSet) {
  (0, _checkPrivateRedeclaration.default)(obj, privateSet);
  privateSet.add(obj);
}

//# sourceMappingURL=classPrivateMethodInitSpec.js.map
