module.exports={A:{A:{"388":"A B","900":"J D E F 5C"},B:{"388":"C K L G M N O","641":"0 1 2 3 4 5 6 7 8 9 q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB","900":"P H Q R S T U V W X Y Z a b c d e f g h i j k l m n o p"},C:{"772":"0 1 2 3 4 5 6 7 8 9 DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC 7C 8C","900":"6C YC I eB J D E F A B C K L G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B ZC 9B aC AC BC CC 9C AD"},D:{"641":"0 1 2 3 4 5 6 7 8 9 q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC","900":"I eB J D E F A B C K L G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B ZC 9B aC AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q R S T U V W X Y Z a b c d e f g h i j k l m n o p"},E:{"772":"A","900":"I eB J D E F B C K L G BD eC CD DD ED FD fC SC TC GD HD ID gC hC UC JD VC iC jC kC lC mC KD WC nC oC pC qC rC LD XC sC tC uC vC wC xC yC zC 0C 1C 2C MD"},F:{"16":"F ND","129":"B C OD PD QD SC 3C RD TC","641":"0 1 2 3 4 5 6 7 8 9 c d e f g h i j k l m n o p q r s t u v w x y z","900":"G M N O fB AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC R S T U V W X Y Z a b"},G:{"900":"E eC SD 4C TD UD VD WD XD YD ZD aD bD cD dD eD fD gD hD iD jD kD lD gC hC UC mD VC iC jC kC lC mC nD WC nC oC pC qC rC oD XC sC tC uC vC wC xC yC zC 0C 1C 2C"},H:{"129":"pD"},I:{"641":"KB","900":"YC I qD rD sD tD 4C uD vD"},J:{"900":"D A"},K:{"129":"A B C SC 3C TC","641":"H"},L:{"900":"KB"},M:{"772":"RC"},N:{"388":"A B"},O:{"900":"UC"},P:{"641":"BB CB DB EB FB GB HB IB JB","900":"I AB wD xD yD zD 0D fC 1D 2D 3D 4D 5D VC WC XC 6D"},Q:{"900":"7D"},R:{"900":"8D"},S:{"772":"AE","900":"9D"}},B:2,C:"CSS page-break properties",D:true};
